@@ -28,5 +28,5 @@ feature_entry = {
 
 
 if __name__ == "__main__":
-    from measure_tests.specific_feature_test import test_specific_feature
+    from ...measure_tests.specific_feature_test import test_specific_feature
     test_specific_feature(AllPairsShortestPathCalculator, is_max_connected=True)
\ No newline at end of file
