@@ -74,6 +74,9 @@ class FeatureCalculator:
         else:
             raise ValueError("Graph must be path to edgelist, nx.Graph or nx.DiGraph")
 
+        # save the nodes before the convert to integers which mix their order
+        self.nodes_order = list(self._graph.nodes)
+
         vertices = np.array(self._graph.nodes)
         should_be_vertices = np.arange(len(vertices))
         self._mapping = {i: v for i, v in enumerate(self._graph)}
@@ -158,13 +161,12 @@ class FeatureCalculator:
         other_order = self._other_features.features
         return np.hstack((raw_features, other_features)), self.build_names_list(raw_order + other_order)
 
-    def get_pandas_df(self, should_sort: bool = False):
+    def get_pandas_df(self):
         feature_matrix, names = self.feature_matrix_with_names()
         features_df = pd.DataFrame(feature_matrix)
         features_df.columns = names
-        features_df.index = self._graph.nodes
-        if should_sort:
-            features_df.sort_index(inplace=True)
+        features_df.index = self.nodes_order
+        features_df.sort_index(inplace=True)
         return features_df
 
     @property
